@@ -66,6 +66,7 @@ from starhtml.datastar import (
     lte,
     # Helper functions
     t,
+    value,
 )
 
 
@@ -214,18 +215,20 @@ class TestSignalsAndPersistence:
 
     def test_ds_signals_kwargs(self):
         """Test ds_signals with kwargs."""
-        result = attrs_of(ds_signals(count=0, name="John", active=True))
+        result = attrs_of(ds_signals(count=0, name=value("John"), active=True))
+        # Primitives auto-wrap, strings need explicit value()
         assert result == {"data-signals-count": "0", "data-signals-name": '"John"', "data-signals-active": "true"}
 
     def test_ds_signals_dict(self):
-        """Test ds_signals with dict argument."""
-        signals = {"count": 0, "name": "John"}
+        """Test ds_signals with dict argument - triggers JSON format."""
+        signals = {"count": 0, "name": value("John")}
         result = attrs_of(ds_signals(signals))
-        assert result == {"data-signals-count": "0", "data-signals-name": '"John"'}
+        # Dict as first arg triggers JSON object format
+        assert result == {"data-signals": '{"count": 0, "name": "John"}'}
 
     def test_ds_signals_with_modifiers(self):
         """Test ds_signals with ifmissing modifier."""
-        result = attrs_of(ds_signals(count=0, ifmissing="warn"))
+        result = attrs_of(ds_signals(count=0, ifmissing="warn"))  # ifmissing is special, not a signal
         assert "data-signals__ifmissing" in result
         assert result["data-signals__ifmissing"] == "warn"
 
@@ -290,8 +293,10 @@ class TestSignalsAndPersistence:
         # Filters
         result = attrs_of(ds_json_signals(include="user", exclude="temp"))
         data = str(result["data-json-signals"])
-        assert '"/user/"' in data
-        assert '"/temp/"' in data
+        assert "/user/" in data
+        assert "/temp/" in data
+        assert "include:" in data
+        assert "exclude:" in data
 
 
 class TestEventHandlers:
@@ -465,9 +470,9 @@ class TestOtherAttributes:
 
     def test_ds_disabled(self):
         """Test ds_disabled function."""
-        assert attrs_of(ds_disabled(True)) == {"data-disabled": "true"}
-        assert attrs_of(ds_disabled(False)) == {"data-disabled": "false"}
-        assert attrs_of(ds_disabled("$isSubmitting")) == {"data-disabled": "$isSubmitting"}
+        assert attrs_of(ds_disabled(True)) == {"data-attr-disabled": "true"}
+        assert attrs_of(ds_disabled(False)) == {"data-attr-disabled": "false"}
+        assert attrs_of(ds_disabled("$isSubmitting")) == {"data-attr-disabled": "$isSubmitting"}
 
     def test_ds_ignore(self):
         """Test ds_ignore function."""
@@ -503,15 +508,16 @@ class TestIntegration:
         assert "data-on-click__once.prevent" in html
         assert "data-class-active" in html
         assert "data-class-loading" in html
-        assert "data-disabled" in html
+        assert "data-attr-disabled" in html
 
     def test_form_with_signals_and_persist(self):
         """Test form with signals and persistence."""
+        # DatastarAttr objects should be applied to the parent element
         form = Form(
             Input(ds_bind("email", case="lower"), type="email"),
             Input(ds_bind("password"), type="password"),
             Button("Login", ds_disabled("!$email || !$password")),
-            ds_signals(email="", password=""),
+            ds_signals(email=value(""), password=value("")),  # These get merged into form attributes
             ds_persist("email"),
             ds_on_submit("login()", "prevent"),
         )
